#include <stdio.h>
#include <windows.h>
#include "COM-RFG.h"

// handle a possible error:
static int Error (int code)
	{
	printf ("%s\n", COM_RFG_ErrorMessage (0));
	return code;
	}

int main (int argc, char * argv[])
	{
	if (argc != 2)
		{
		printf ("The number of the COM port must be specified!\n");
		return -1;
		}
	// check the DLL version:
	WORD DLL_Version = COM_RFG_Version();
	if ((DLL_Version & 0xFF00) != 0x0100)
		{
		printf ("Wrong DLL Version: expected 1.x, found %d.%02d\n",
			DLL_Version / 0x100, DLL_Version & 0xFF);
		return 1;
		}

	// open the port 0:
	WORD COMNumber;
	sscanf (argv[1], "%hu", &COMNumber);
	if (COM_RFG_Open (0, COMNumber))
		return Error (2); // handle a possible error

	// Get interlock state:
	BOOL Closed;
	if (COM_RFG_Get_InterlockState (0, Closed))
		return Error (3); // handle a possible error
	printf ("Interlock: %s\n", Closed ? "closed" : "open");

	// Get RFG data:
	double Amplitude1, Amplitude2, VoltageDrain;
	long Frequency;
	double TemperatureHeatsink, TemperatureCoil;
	if (COM_RFG_Get_RFGData (0, Amplitude1, Amplitude2,
		VoltageDrain, Frequency,
		TemperatureHeatsink, TemperatureCoil))
		return Error (4); // handle a possible error
	printf ("Measured RF output values:\n"
		"\tAmplitudes: %.1lfV, %.1lfV\n"
		"\tFrequency:  %.4fMHz\n",
		Amplitude1, Amplitude2, 1E-6*Frequency);

	// Get power supply data:
	double Voltage, Current, Temperature;
	if (COM_RFG_Get_PowerData (0, Voltage, Current, Temperature))
		return Error (5); // handle a possible error
	printf ("Measured supply values:\n"
		"\tVoltage: %5.2lfV\n"
		"\tCurrent: %5.2lfA\n"
		"\tPower:   %5.1lfW\n",
		Voltage, Current, Voltage*Current);

	//finish the program:
	return 0;
	}

